@@ -67,7 +67,7 @@ class ObjPanel_Empty(ObjPanel):
             wx.EmptyString,
             wx.DefaultPosition,
             wx.Size(-1, -1),
-            wx.TE_READONLY,
+            style=wx.TE_READONLY,
         )
         hsizer.Add(self.obj_txt, 1, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 0)
 
@@ -92,7 +92,7 @@ class ObjPanel_Default(ObjPanel):
             self.entry.obj_str,
             wx.DefaultPosition,
             wx.Size(-1, -1),
-            wx.TE_READONLY,
+            style=wx.TE_READONLY,
         )
         hsizer.Add(self.obj_txt, 1, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 0)
 
@@ -118,6 +118,7 @@ class ObjPanel_String(ObjPanel):
             self,
             wx.ID_ANY,
             self.entry.obj_str,
+            style=wx.TE_PROCESS_ENTER,
         )
         hsizer.Add(self.obj_txt, 1, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 0)
 
@@ -140,7 +141,12 @@ class ObjPanel_Integer(ObjPanel):
 
         # Obj
         hsizer = wx.BoxSizer(wx.HORIZONTAL)
-        self.obj_txtctrl = wx.TextCtrl(self, wx.ID_ANY, self.entry.obj_str)
+        self.obj_txtctrl = wx.TextCtrl(
+            self,
+            wx.ID_ANY,
+            self.entry.obj_str,
+            style=wx.TE_PROCESS_ENTER,
+        )
         hsizer.Add(self.obj_txtctrl, 1, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 0)
 
         self.SetSizer(hsizer)
@@ -172,7 +178,12 @@ class ObjPanel_Flag(ObjPanel):
 
         # Obj
         hsizer = wx.BoxSizer(wx.HORIZONTAL)
-        self.obj_txtctrl = wx.TextCtrl(self, wx.ID_ANY, self.entry.obj_str)
+        self.obj_txtctrl = wx.TextCtrl(
+            self,
+            wx.ID_ANY,
+            self.entry.obj_str,
+            style=wx.TE_PROCESS_ENTER,
+        )
         hsizer.Add(self.obj_txtctrl, 1, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 0)
 
         self.SetSizer(hsizer)
@@ -203,7 +214,12 @@ class ObjPanel_Bytes(ObjPanel):
 
         # Obj
         hsizer = wx.BoxSizer(wx.HORIZONTAL)
-        self.obj_txtctrl = wx.TextCtrl(self, wx.ID_ANY, self.entry.obj_str)
+        self.obj_txtctrl = wx.TextCtrl(
+            self,
+            wx.ID_ANY,
+            self.entry.obj_str,
+            style=wx.TE_PROCESS_ENTER,
+        )
         hsizer.Add(self.obj_txtctrl, 1, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 0)
 
         self.SetSizer(hsizer)
@@ -240,7 +256,7 @@ class ObjPanel_Enum(ObjPanel):
 
         self.obj_combobox = wx.ComboBox(
             self,
-            style=wx.CB_DROPDOWN,
+            style=wx.CB_DROPDOWN | wx.TE_PROCESS_ENTER,
         )
         hsizer.Add(self.obj_combobox, 1, wx.ALL | wx.ALIGN_CENTER_VERTICAL, 0)
 
@@ -436,7 +452,7 @@ class ObjPanel_Timestamp(ObjPanel):
             self.entry.obj_str,
             wx.DefaultPosition,
             wx.DefaultSize,
-            wx.TE_READONLY,
+            style=wx.TE_READONLY,
         )
         hsizer.Add(self.obj_txtctrl, 1, wx.LEFT | wx.ALIGN_CENTER_VERTICAL, 5)
 
@@ -446,7 +462,8 @@ class ObjPanel_Timestamp(ObjPanel):
     def get_new_obj(self) -> Any:
         date: wx.DateTime = self.date_picker.GetValue()
         time: wx.DateTime = self.time_picker.GetValue()
-        new_obj = arrow.Arrow(
+        obj_type = type(self.entry.obj)
+        new_obj = obj_type(
             year=date.year,
             month=date.month + 1,  # in wx.adc.DatePickerCtrl the month start with 0
             day=date.day,
@@ -1463,10 +1480,7 @@ class EntryTimestamp(EntrySubconstruct):
 
     @property
     def obj_str(self) -> str:
-        if isinstance(self.obj, (arrow.Arrow)):
-            return self.obj.format("YYYY-MM-DD HH:mm:ss ZZ")
-        else:
-            return str(self.obj)
+        return str(self.obj)
 
     def create_obj_panel(self, parent) -> ObjPanel:
         return ObjPanel_Timestamp(parent, self)
@@ -1889,7 +1903,7 @@ construct_entry_mapping: t.Dict[
     # tunneling and byte/bit swapping ###########
     cs.RawCopy: EntryRawCopy,
     # cs.Prefixed
-    # cs.FixedSized
+    cs.FixedSized: EntryTransparentSubcon,
     # cs.NullTerminated
     # cs.NullStripped
     # cs.RestreamData
